@@ -19,7 +19,7 @@
 #include <skalibs/bytestr.h>
 #include <skalibs/cbuffer.h>
 #include <skalibs/cdb.h>
-#include <skalibs/cdb_make.h>
+#include <skalibs/cdbmake.h>
 #include <skalibs/direntry.h>
 #include <skalibs/diuint32.h>
 #include <skalibs/diuint.h>
@@ -34,11 +34,9 @@
 #include <skalibs/gccattributes.h>
 #include <skalibs/genalloc.h>
 #include <skalibs/genwrite.h>
-#include <skalibs/iobuffer.h>
 #include <skalibs/iopause.h>
 #include <skalibs/lolstdio.h>
 #include <skalibs/netstring.h>
-#include <skalibs/nsig.h>
 #include <skalibs/segfault.h>
 #include <skalibs/selfpipe.h>
 #include <skalibs/setgroups.h>
