@@ -4,7 +4,7 @@
 #include <errno.h>
 #include <skalibs/gensetdyn.h>
 
-int gensetdyn_iter_withcancel (gensetdyn *g, iterfunc_t_ref f, iterfunc_t_ref cancelf, void *stuff)
+int gensetdyn_iter_withcancel (gensetdyn *g, iter_func_ref f, iter_func_ref cancelf, void *stuff)
 {
   uint32_t n = gensetdyn_iter_nocancel(g, gensetdyn_n(g), f, stuff) ;
   if (n < gensetdyn_n(g))
