@@ -3,7 +3,7 @@
 #include <errno.h>
 #include <skalibs/allreadwrite.h>
 
-size_t allreadwrite (iofunc_t_ref op, int fd, char *buf, size_t len)
+size_t allreadwrite (io_func_ref op, int fd, char *buf, size_t len)
 {
   size_t written = 0 ;
   while (len)
