@@ -5,7 +5,7 @@
 
 #ifdef SKALIBS_HASPPOLL
 
-iopause_func_t_ref const iopause_ = &iopause_ppoll ;
+iopause_func_ref const iopause_ = &iopause_ppoll ;
 
 #else
 
@@ -13,11 +13,11 @@ iopause_func_t_ref const iopause_ = &iopause_ppoll ;
 
 #ifdef SKALIBS_FLAG_PREFERSELECT
 
-iopause_func_t_ref const iopause_ = &iopause_select ;
+iopause_func_ref const iopause_ = &iopause_select ;
 
 #else
 
-iopause_func_t_ref const iopause_ = &iopause_poll ;
+iopause_func_ref const iopause_ = &iopause_poll ;
 
 #endif
 
