@@ -3,6 +3,7 @@
 /* MT-unsafe */
 
 #include <signal.h>
+
 #include <skalibs/sysdeps.h>
 #include "selfpipe-internal.h"
 
@@ -14,18 +15,16 @@ int selfpipe_fd = -1 ;
 
 #else
 
-#include <errno.h>
+#include <unistd.h>
+
 #include <skalibs/allreadwrite.h>
-#include <skalibs/djbunix.h>
 
 int selfpipe[2] = { -1, -1 } ;
 
-static void selfpipe_trigger (int s)
+void selfpipe_tophalf (int s)
 {
   unsigned char c = (unsigned char)s ;
-  fd_write(selfpipe[1], (char *)&c, 1) ;
+  write(selfpipe[1], (char *)&c, 1) ;
 }
 
-struct skasigaction const selfpipe_ssa = { &selfpipe_trigger, SKASA_NOCLDSTOP | SKASA_MASKALL } ;
-
 #endif
