@@ -1,11 +1,12 @@
 /* ISC license. */
 
 #include <errno.h>
+
 #include <skalibs/error.h>
 #include <skalibs/socket.h>
 #include <skalibs/ip46.h>
 
-int socket_deadlineconnstamp46 (int s, ip46_t const *i, uint16_t port, tain_t const *deadline, tain_t *stamp)
+int socket_deadlineconnstamp46 (int s, ip46 const *i, uint16_t port, tain const *deadline, tain *stamp)
 {
   int e = errno ;
   if (socket_connect46(s, i, port) >= 0) return 1 ;
