@@ -6,7 +6,7 @@
 
 #ifdef SKALIBS_FLAG_CLOCKISTAI
 
-int sysclock_from_tai (uint64_t *u, tai_t const *t)
+int sysclock_from_tai (uint64_t *u, tai const *t)
 {
   if (t->x < 10U) return (errno = EINVAL, 0) ;
   *u = t->x - 10U ;
@@ -17,7 +17,7 @@ int sysclock_from_tai (uint64_t *u, tai_t const *t)
 
 #include <skalibs/djbtime.h>
 
-int sysclock_from_tai (uint64_t *u, tai_t const *t)
+int sysclock_from_tai (uint64_t *u, tai const *t)
 {
   return utc_from_tai(u, t) ;
 }
