@@ -22,9 +22,9 @@ static ssize_t get (struct blah_s *blah)
   return buffer_getall(blah->b, blah->s, blah->len, &blah->w) ;
 }
 
-size_t buffer_timed_get (buffer *b, char *s, size_t len, tain_t const *deadline, tain_t *stamp)
+size_t buffer_timed_get (buffer *b, char *s, size_t len, tain const *deadline, tain *stamp)
 {
   struct blah_s blah = { .b = b, .s = s, .len = len, .w = 0 } ;
-  timed_get(&blah, (initfunc_t_ref)&getfd, (getfunc_t_ref)&get, deadline, stamp) ;
+  timed_get(&blah, (init_func_ref)&getfd, (get_func_ref)&get, deadline, stamp) ;
   return blah.w ;
 }
