@@ -2,10 +2,11 @@
 
 #include <sys/types.h>
 #include <errno.h>
+
 #include <skalibs/kolbak.h>
 #include <skalibs/unixmessage.h>
 
-int kolbak_enqueue (kolbak_queue_t *q, unixmessage_handler_func_t *f, void *data)
+int kolbak_enqueue (kolbak_queue *q, unixmessage_handler_func_ref f, void *data)
 {
   size_t newtail = (q->tail + 1) % q->n ;
   if (newtail == q->head) return (errno = ENOBUFS, 0) ;
