@@ -2,4 +2,4 @@
 
 #include <skalibs/textclient.h>
 
-textclient_t const textclient_zero = TEXTCLIENT_ZERO ;
+textclient const textclient_zero = TEXTCLIENT_ZERO ;
