@@ -4,4 +4,4 @@
 
 #include <skalibs/unixmessage.h>
 
-unixmessage_sender_t unixmessage_sender_1_ = UNIXMESSAGE_SENDER_INIT(1) ;
+unixmessage_sender unixmessage_sender_1_ = UNIXMESSAGE_SENDER_INIT(1) ;
